#!/bin/sh
#
# usage: run-hostap.sh <interface> <ssid>
#

if [ $# -lt 2 ]; then
    echo "usage: $0 <interface> <ssid>"
    exit 1
fi

TOPDIR=`dirname $0`/..
DHCPCONF=$TOPDIR/etc/dhcpd.conf
DHCPLEAS=$TOPDIR/etc/dhcpd.leases
INTERFACE=$1
SSID=$2
MYIP=169.254.133.7

if [ ! -f $TOPDIR/etc/dhcpd.conf ]; then
    echo "$TOPDIR/etc/dhcpd.conf: File not found"
    exit 1
fi

if [ ! -f $DHCPLEAS ]; then
    touch $DHCPLEAS
fi

hostap_start()
{
    echo "Starting HostAP..."

    if [ "$OSTYPE" = "FreeBSD" ]; then
        ifconfig $INTERFACE down
        ifconfig $INTERFACE -mediaopt monitor
        ifconfig $INTERFACE inet $MYIP netmask 255.255.0.0 channel 1 ssid "$SSID" mediaopt hostap up
    else
	ifconfig $INTERFACE down
	iwpriv $INTERFACE monitor 0	# HostAP
	iwpriv $INTERFACE mode 2	# MadWifi: 802.11b only
	iwpriv $INTERFACE authmode 1	# MadWifi: open authentication
	iwpriv $INTERFACE hide_ssid 1	# MadWifi: "closed network"
        iwconfig $INTERFACE channel 1 essid "$SSID" mode Master 
        ifconfig $INTERFACE inet $MYIP netmask 255.255.0.0 up
    fi
}

hostap_stop()
{
    echo "Stopping HostAP..."

    if [ "$OSTYPE" = "FreeBSD" ]; then
	ifconfig $INTERFACE down
        ifconfig $INTERFACE inet $MYIP delete -mediaopt hostap ssid ""
        exit 1
    else
	ifconfig $INTERFACE down
	ifconfig $INTERFACE inet 0.0.0.0
	iwconfig $INTERFACE essid "test" mode managed
    fi
}

trap hostap_stop INT

hostap_start

# Start Service Manager
(cd $TOPDIR/modules/servers/ && ./main.rb $MYIP) &

# Start DHCP
dhcpd -d -f -cf $DHCPCONF -lf $DHCPLEAS $1

